Annotation Type Argument
Annotation used to indicate that a method parameter is a command argument
-
Required Element Summary
Required Elements -
Optional Element Summary
Optional Elements
-
Element Details
-
value
@NonNull String valueArgument name- Returns:
- Argument name
-
-
-
parserName
@NonNull String parserNameName of the argument parser- Returns:
- Argument name
- Default:
- ""
-
suggestions
@NonNull String suggestionsName of the suggestions provider to use. If the string is left empty, the default provider for the argument parser will be used. Otherwise, theParserRegistryinstance in theCommandManagerwill be queried for a matching suggestion provider.For this to work, the suggestion needs to be registered in the parser registry. To do this, use
ParserRegistry.registerSuggestionProvider(String, BiFunction). The registry instance can be retrieved usingCommandManager.getParserRegistry().- Returns:
- The name of the suggestion provider, or
""if the default suggestion provider for the argument parser should be used instead - Since:
- 1.1.0
- Default:
- ""
-
defaultValue
@NonNull String defaultValueGet the default value- Returns:
- Default value
- Default:
- ""
-
description
@NonNull String descriptionThe argument description- Returns:
- Argument description
- Default:
- ""
-