Package cloud.commandframework.annotations


package cloud.commandframework.annotations
Annotation parsing related classes
  • Class Summary
    Class
    Description
    Parser that parses class instances commands
  • Annotation Types Summary
    Annotation Type
    Description
    Annotation used to indicate that a method parameter is a command argument
    Maps to StandardParameters.DESCRIPTION
    Used to declare a class method as a command method
    Equivalent to Command.Builder.permission(String)
    Require confirmation for the command
    Indicates that the parameter should be treated like a CommandFlag.
    Indicates that the command should be hidden.
    Creates a command proxy for the command.
    Annotation version of adding RegexPreprocessor as a preprocessor using CommandArgument.addPreprocessor(BiFunction)