Package cloud.commandframework.annotations
package cloud.commandframework.annotations
Annotation parsing related classes
-
Class Summary
-
Annotation Types SummaryAnnotation TypeDescriptionAnnotation used to indicate that a method parameter is a command argumentMaps to
StandardParameters.DESCRIPTIONUsed to declare a class method as a command methodEquivalent toCommand.Builder.permission(String)Require confirmation for the commandIndicates that the parameter should be treated like aCommandFlag.Indicates that the command should be hidden.Creates a command proxy for the command.Annotation version of addingRegexPreprocessoras a preprocessor usingCommandArgument.addPreprocessor(BiFunction)